==> getsocial_flutter_sdk-7.5.0.tar.gz: lib/current_user.dart <==
import 'dart:convert';

import 'usermanagement/identity.dart';
import 'usermanagement/conflict_user.dart';
import 'usermanagement/user_update.dart';
import 'src/private_user.dart';
import 'src/native_bridge.dart';

class CurrentUser extends PrivateUser {
  CurrentUser.fromJSON(Map<String, dynamic> json) : super.fromJSON(json);

  ///
  /// Requests a bulk change of properties for the current user.
  ///
  /// [update] New user details.
  ///
  Future updateDetails(UserUpdate update) {
    return NativeBridge.async(
        'CurrentUser.updateDetails', jsonEncode(update.toJson()));
  }

  ///
  /// Adds Identity for the specified provider.
  ///
  /// [identity] Identity to be added.
  /// [onSuccess]  A callback to indicate if this operation was successful.
  /// [onConflict] Called if there was a conflict.
  /// [onError]  Called if operation failed.
  ///
  void addIdentity(Identity identity, Function onSuccess,
      Function(ConflictUser) onConflict, Function onError) {
    NativeBridge.async('CurrentUser.addIdentity', jsonEncode(identity.toJSON()))
        .then((value) {
              if (jsonDecode(value)['result'] == '') {
                  onSuccess();
              } else {
                onConflict(ConflictUser.fromJSON(jsonDecode(value)));
              }
            })
        .catchError(onError);
  }

  ///
  /// Removes Identity for the specified provider.
  ///
  /// [providerId] The provider connected to an auth identity on the current user to remove.
  /// Valid provider ids are found in [IdentityProviderIds] in addition to custom providers.
  ///
  Future removeIdentity(String providerId) {
    return NativeBridge.async('CurrentUser.removeIdentity', providerId);
  }

  @override
  String toString() {
    return 'CurrentUser{${super.toString()}';
  }
}

==> getsocial_flutter_sdk-7.6.0.tar.gz: lib/current_user.dart <==
import 'dart:convert';

import 'usermanagement/identity.dart';
import 'usermanagement/conflict_user.dart';
import 'usermanagement/user_update.dart';
import 'src/private_user.dart';
import 'src/native_bridge.dart';

class CurrentUser extends PrivateUser {
  CurrentUser.fromJSON(Map<String, dynamic> json) : super.fromJSON(json);

  ///
  /// Requests a bulk change of properties for the current user.
  ///
  /// [update] New user details.
  ///
  Future updateDetails(UserUpdate update) {
    return NativeBridge.async(
        'CurrentUser.updateDetails', jsonEncode(update.toJson()));
  }

  ///
  /// Adds Identity for the specified provider.
  ///
  /// [identity] Identity to be added.
  /// [onSuccess]  A callback to indicate if this operation was successful.
  /// [onConflict] Called if there was a conflict.
  /// [onError]  Called if operation failed.
  ///
  void addIdentity(Identity identity, Function onSuccess,
      Function(ConflictUser) onConflict, Function onError) {
    NativeBridge.async('CurrentUser.addIdentity', jsonEncode(identity.toJSON()))
        .then((value) {
      if (jsonDecode(value)['result'] == '') {
        onSuccess();
      } else {
        onConflict(ConflictUser.fromJSON(jsonDecode(value)));
      }
    }).catchError(onError);
  }

  ///
  /// Removes Identity for the specified provider.
  ///
  /// [providerId] The provider connected to an auth identity on the current user to remove.
  /// Valid provider ids are found in [IdentityProviderIds] in addition to custom providers.
  ///
  Future removeIdentity(String providerId) {
    return NativeBridge.async('CurrentUser.removeIdentity', providerId);
  }

  @override
  String toString() {
    return 'CurrentUser{${super.toString()}';
  }
}
